package com.ruoyi.tcZz.service;

import com.ruoyi.tcZz.domain.TcFb;

import java.util.List;

/**
 * 上级媒体、本地发布Service接口
 *
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcFbService {
    /**
     * 查询上级媒体、本地发布
     *
     * @param id 上级媒体、本地发布主键
     * @return 上级媒体、本地发布
     */
    public TcFb selectTcFbById(Long id);

    /**
     * 查询上级媒体、本地发布列表
     *
     * @param tcFb 上级媒体、本地发布
     * @return 上级媒体、本地发布集合
     */
    public List<TcFb> selectTcFbList(TcFb tcFb);

    /**
     * 新增上级媒体、本地发布
     *
     * @param tcFb 上级媒体、本地发布
     * @return 结果
     */
    public int insertTcFb(TcFb tcFb);

    /**
     * 修改上级媒体、本地发布
     *
     * @param tcFb 上级媒体、本地发布
     * @return 结果
     */
    public int updateTcFb(TcFb tcFb);

    /**
     * 批量删除上级媒体、本地发布
     *
     * @param ids 需要删除的上级媒体、本地发布主键集合
     * @return 结果
     */
    public int deleteTcFbByIds(Long[] ids);

    /**
     * 删除上级媒体、本地发布信息
     *
     * @param id 上级媒体、本地发布主键
     * @return 结果
     */
    public int deleteTcFbById(Long id);

    /**
     * 导入上级媒体、本地发布信息
     *
     * @return 结果
     */
    public String importUser(List<TcFb> tccFbList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
