package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcDy;
import com.ruoyi.tcZz.domain.TcFb;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcFbService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 上级媒体、本地发布Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "上级媒体、本地发布")
@RequestMapping("/tcZz/networkEcology/fb")
public class TcFbController extends BaseController {
    @Autowired
    private ITcFbService tcFbService;

    /**
     * 查询上级媒体、本地发布列表
     */
    @ApiOperation(value = "查询上级媒体、本地发布列表", response = TcFb.class)
    @GetMapping("/list")
    public TableDataInfo list(TcFb tcFb) {
        startPage();
        List<TcFb> list = tcFbService.selectTcFbList(tcFb);
        return getDataTable(list);
    }

    /**
     * 导出上级媒体、本地发布列表
     */
    @ApiOperation(value = "导出上级媒体、本地发布列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcFb tcFb) {
        List<TcFb> list = tcFbService.selectTcFbList(tcFb);
        ExcelUtil<TcFb> util = new ExcelUtil<TcFb>(TcFb.class);
        util.exportExcel(response, list, "上级媒体、本地发布数据");
    }

    /**
     * 获取上级媒体、本地发布详细信息
     */
    @ApiOperation(value = "获取上级媒体、本地发布详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcFbService.selectTcFbById(id));
    }

    /**
     * 新增上级媒体、本地发布
     */
    @ApiOperation(value = "新增上级媒体、本地发布")
    @PostMapping
    public AjaxResult add(@RequestBody TcFb tcFb) {
        return toAjax(tcFbService.insertTcFb(tcFb));
    }

    /**
     * 修改上级媒体、本地发布
     */
    @ApiOperation(value = "修改上级媒体、本地发布")
    @PutMapping
    public AjaxResult edit(@RequestBody TcFb tcFb) {
        return toAjax(tcFbService.updateTcFb(tcFb));
    }

    /**
     * 删除上级媒体、本地发布
     */
    @ApiOperation(value = " 删除上级媒体、本地发布")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcFbService.deleteTcFbByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcFb> util = new ExcelUtil<TcFb>(TcFb.class);
        List<TcFb> tccFbList = util.importExcel(file.getInputStream());
        tcFbService.importUser(tccFbList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcFbService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcFb> util = new ExcelUtil<TcFb>(TcFb.class);
        util.importTemplateExcel(response, " 上级媒体、本地发布");
    }
}
